@@ -31,7 +31,8 @@
 Configuration* Configuration::instance_ = nullptr;
 
 Configuration::Configuration(QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      m_trans(nullptr)
 {
     QString recodfile = QDir::homePath() + "/.cache/ukui-greeter.conf";
     qDebug() << recodfile;
@@ -63,6 +64,15 @@ void Configuration::setValue(const QString &key, const QVariant &value)
     configSettings->endGroup();
 }
 
+bool Configuration::hasValue(const QString &key)
+{
+    configSettings->beginGroup("Greeter");
+    bool value = configSettings->contains(key);
+    configSettings->endGroup();
+
+    return value;
+}
+
 QString Configuration::getLastLoginUser()
 {
     recordSettings->beginGroup("Greeter");
@@ -79,6 +89,14 @@ void Configuration::saveLastLoginUser(const QString &userRealName)
     recordSettings->sync();
 }
 
+void Configuration::saveLastLoginUser1(const QString &userRealName)
+{
+    recordSettings->beginGroup("Greeter");
+    recordSettings->setValue("lastLoginUser1", userRealName);
+    recordSettings->endGroup();
+    recordSettings->sync();
+}
+
 bool Configuration::getLastNumLock()
 {
     recordSettings->beginGroup("Greeter");
@@ -121,6 +139,12 @@ QString getSystemDistrib()
     return distribId;
 }
 
+bool Configuration::getUseFirstDevice()
+{
+    QSettings settings("/etc/biometric-auth/ukui-biometric.conf", QSettings::IniFormat);
+    return settings.value("UseFirstDevice").toBool();
+}
+
 /**
  * @brief logoGenerator
  * @param text
@@ -179,13 +203,15 @@ QPixmap Configuration::getLogo()
 
 QString Configuration::getDefaultBackgroundName()
 {
-
+/*
     if(getSystemDistrib().contains("Ubuntu",Qt::CaseInsensitive))
         return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
     else if(getSystemVersion().contains("V10.1",Qt::CaseInsensitive))
         return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
     else if(getSystemVersion().contains("V10",Qt::CaseInsensitive))
         return "/usr/share/backgrounds/kylin/kylin-background.png";
-	else 
-		return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";	
+    else 
+        return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";	
+*/
+    return "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
 }
