@@ -40,5 +40,7 @@ extern float scale;     //缩放比例
 extern int fontSize;    //字体大小
 
 QPixmap scaledPixmap(int width, int height, QString url);
+bool isPicture(QString filepath);
+QString ElideText(QFont font,int width,QString strInfo);
 #endif // GLOBALV_H
 
