@@ -21,6 +21,7 @@
 #include <QDesktopWidget>
 #include <QDebug>
 #include <QBitArray>
+#include <QTextCodec>
 #include "globalv.h"
 #include "common/configuration.h"
 
@@ -31,6 +32,9 @@ GreeterWrapper::GreeterWrapper(QObject *parent) : QLightDM::Greeter(parent)
         qDebug() << "connect to Daemon failed";
         exit(1);
     }
+
+    drawBackgroundType = 0;
+    drawBackgroundColor = 0x0;
 }
 
 void GreeterWrapper::setLang(const QString &lang)
@@ -63,25 +67,39 @@ void GreeterWrapper::setUserName(const QString &userName)
     m_userName = userName;
 }
 
-void GreeterWrapper::setrootWindowBackground(QString path)
+void GreeterWrapper::setrootWindowBackground(int type,unsigned int color,QString filename)
 {
-    m_rootWindowBackground = path;
+    drawBackgroundType = type;
+    if(drawBackgroundType == rootWinPicture)
+        m_rootWindowBackground = filename;
+    else if(drawBackgroundType == rootWinColor)
+        drawBackgroundColor = color;  
+}
+
+bool GreeterWrapper::getdrawBackgroundIsStarted()
+{
+    return drawBackgroundIsStarted;
 }
 
 void GreeterWrapper::setrootWindow()
 {
-     Configuration  *m_configure = Configuration::instance();
-     QString m_defaultBackgroundPath = m_configure->getDefaultBackgroundName();
-     if(m_rootWindowBackground.isEmpty())
-         m_rootWindowBackground = m_defaultBackgroundPath;
-     if(m_rootWindowBackground.isEmpty())
-         return;
-     char*  path;
-     QByteArray ba = m_rootWindowBackground.toLatin1(); // must
-     path=ba.data();
+    drawBackgroundIsStarted = true;
+    Configuration  *m_configure = Configuration::instance();
+    QString m_defaultBackgroundPath = m_configure->getDefaultBackgroundName();
+    if(m_rootWindowBackground.isEmpty())
+        m_rootWindowBackground = m_defaultBackgroundPath;
+    if(m_rootWindowBackground.isEmpty())
+        return;
 
-     QDesktopWidget desktop;
-     setRootWindowBackground(path);
+    char*  path;
+    QByteArray ba = m_rootWindowBackground.toLatin1(); // must
+    path=ba.data();
+
+    if(drawBackgroundType == 0)
+     	setRootWindowBackground(0,0,path);
+    else
+        setRootWindowBackground(1,drawBackgroundColor,NULL);
+    drawBackgroundIsStarted = false;
 }
 
 QString GreeterWrapper::getEnsureShareDir(QString username)
@@ -93,13 +111,11 @@ void GreeterWrapper::startSession()
 {
     if(isAuthenticated())
         Q_EMIT authenticationSucess();
-    //设置language
-    if(!m_language.isEmpty()) {
-        setLanguage(m_language);
-    }
 
     //启动session
-    setrootWindow();
+    //setrootWindow();
+    draw_background();
+    qDebug()<<"start session";
     if(!startSessionSync(m_session)) {
         Q_EMIT startSessionFailed();
         Q_EMIT showMessage(tr("failed to start session."), QLightDM::Greeter::MessageTypeError);
