@@ -20,7 +20,10 @@
 #define MAINWINDOW_H
 
 #include <QWidget>
+#include <QtConcurrent/QtConcurrentRun>
 #include <QSharedPointer>
+#include <QAbstractNativeEventFilter>
+
 #include "screenmodel.h"
 
 
@@ -57,7 +60,7 @@ class GreeterWindow;
 class Configuration;
 class MonitorWatcher;
 class QTimer;
-class MainWindow : public QWidget
+class MainWindow : public QWidget , public QAbstractNativeEventFilter
 {
     Q_OBJECT
 public:
@@ -67,6 +70,7 @@ public:
 protected:
     void paintEvent(QPaintEvent *);
     void mouseMoveEvent(QMouseEvent *);
+    virtual bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
 
 signals:
     void activeScreenChanged(const QRect& rect);
@@ -76,6 +80,8 @@ private slots:
     void onScreenCountChanged(int newCount);
     void onTransition();
     void screenCountEvent();
+    void RRScreenChangeEvent();
+    QString findTouchScreen();
 
 private:
     void moveToScreen(QScreen *screen = nullptr);
@@ -84,7 +90,7 @@ private:
     void drawTransitionAlpha(const QRect &rect);
     void drawBackground(QSharedPointer<Background> &, const QRect &, float alpha = 1.0);
     QPixmap * getBackground(const QString &path, const QRect &rect);
-
+    void showLater();
 private:
     ScreenModel     *m_screenModel;
     GreeterWindow   *m_greeterWnd;
@@ -97,19 +103,25 @@ private:
     QString          m_lastBackgroundPath;
     QPixmap          m_logo;
     QPixmap          m_cof;
+    QPixmap         *pixmap;
     //QMap<QPair<m_backgroundPath, resolution>, background>
     //对每张背景图片的不同分辨率进行缓存，减少CPU占用率（这里分辨率格式：1080x960）
     QMap<QPair<QString, QString>, QPixmap*>   m_backgrounds;
 
     static bool      m_first;
-    MonitorWatcher  *m_monitorWatcher;
-    QTimer          *m_timer;
+    //MonitorWatcher  *m_monitorWatcher;
+    QTimer          *m_timer = nullptr;
 
 //    bool             m_switchBackground;
     QSharedPointer<Background> m_background;
     Transition       m_transition;
 //    QPainter        *m_painter;
     BackgroundMode   m_backgroundMode;
+    QFuture<void>    future;
+    int rr_event_base;
+    int rr_error_base;
+
+    int m_monitorCount;
 };
 
 #endif // MAINWINDOW_H
