@@ -17,4 +17,5 @@
  * 02110-1301, USA.
 **/
 
-void setRootWindowBackground(char *filename);
+void setRootWindowBackground(bool type,unsigned int color,char *filename);
+void draw_background();
