@@ -69,6 +69,8 @@ void SessionWindow::addSessionLabels()
     for(int i = 0; i < m_sessionsModel->rowCount(); i++) {
         QString sessionName = m_sessionsModel->index(i, 0).data().toString();
         QString sessionKey = m_sessionsModel->index(i, 0).data(Qt::UserRole).toString();
+        if(sessionKey == "lightdm-xsession")
+            continue;
         QAction *action = new QAction(QIcon(getSessionIcon(sessionKey)), sessionName, this);
         action->setData(sessionKey);
         addAction(action);
@@ -91,10 +93,12 @@ void SessionWindow::onSessionMenuTrigged(QAction *action)
     emit sessionChanged(sessionkey);
 }
 
-
 QString SessionWindow::getSessionIcon(const QString &session)
 {
     QString sessionPrefix = session.left(session.indexOf('-'));
+    if(session == "ukui-wayland")
+        sessionPrefix = "ukui_wayland";
+
     QString sessionIcon = IMAGE_DIR + QString("badges/%1_badge.svg").arg(sessionPrefix.toLower());
     QFile iconFile(sessionIcon);
     if(!iconFile.exists()){
