@@ -1,32 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="es">
-<context>
-    <name>BioAuthentication</name>
-    <message>
-        <source>authentication failed, restart after 2 seconds</source>
-        <translation type="obsolete">autenticación fallida, reinicie después de 2 segundos</translation>
-    </message>
-</context>
-<context>
-    <name>BioDeviceView</name>
-    <message>
-        <source>password login</source>
-        <translation type="obsolete">contraseña de acceso</translation>
-    </message>
-    <message>
-        <source>fingerprint</source>
-        <translation type="obsolete">huella dactilar</translation>
-    </message>
-    <message>
-        <source>fingerevin</source>
-        <translation type="obsolete">fingerevin</translation>
-    </message>
-    <message>
-        <source>iris</source>
-        <translation type="obsolete">iris</translation>
-    </message>
-</context>
 <context>
     <name>BiometricAuthWidget</name>
     <message>
@@ -90,12 +64,8 @@
 <context>
     <name>GreeterWindow</name>
     <message>
-        <source>CN</source>
-        <translation type="obsolete">CN</translation>
-    </message>
-    <message>
-        <source>EN</source>
-        <translation type="obsolete">ES</translation>
+        <source>Login</source>
+        <translation type="unfinished">Iniciar sesión</translation>
     </message>
 </context>
 <context>
@@ -108,8 +78,12 @@
 <context>
     <name>IconEdit</name>
     <message>
-        <source>Login</source>
-        <translation type="obsolete">Iniciar sesión</translation>
+        <source>Password: </source>
+        <translation type="unfinished">Contraseña: </translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -137,21 +111,9 @@
         <source>Password: </source>
         <translation>Contraseña: </translation>
     </message>
-    <message>
-        <source>login:</source>
-        <translation type="vanished">iniciar sesión:</translation>
-    </message>
     <message>
         <source>Incorrect password, please input again</source>
-        <translation type="unfinished">Contraseña incorrecta, por favor ingrese nuevamente</translation>
-    </message>
-    <message>
-        <source>please select the type of authentication</source>
-        <translation type="obsolete">Por favor seleccione el tipo de autenticación</translation>
-    </message>
-    <message>
-        <source>Incorrect user name, please input again</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Contraseña incorrecta, por favor ingrese nuevamente</translation>
     </message>
     <message>
         <source>Retry</source>
@@ -173,6 +135,18 @@
         <source>Username</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Authentication failure, Please try again</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please enter your password or enroll your fingerprint </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too many unsuccessful attempts,please enter password.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -183,18 +157,6 @@
 </context>
 <context>
     <name>PowerManager</name>
-    <message>
-        <source>suspend</source>
-        <translation type="obsolete">suspender</translation>
-    </message>
-    <message>
-        <source>restart</source>
-        <translation type="obsolete">reiniciar</translation>
-    </message>
-    <message>
-        <source>shutdown</source>
-        <translation type="obsolete">apagar</translation>
-    </message>
     <message>
         <source>Restart</source>
         <translation type="unfinished"></translation>
@@ -211,50 +173,9 @@
         <source>Sleep</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>PowerWindow</name>
     <message>
-        <source>Goodbye. Would you like to…</source>
-        <translation type="obsolete">Adiós. Te gustaria…</translation>
-    </message>
-    <message>
-        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
-        <translation type="vanished">Otros usuarios están actualmente conectados a esta computadora, apagar ahora también cerrará estas otras sesiones.</translation>
-    </message>
-    <message>
-        <source>suspend</source>
-        <translation type="vanished">suspender</translation>
-    </message>
-    <message>
-        <source>hibernate</source>
-        <translation type="vanished">hibernar</translation>
-    </message>
-    <message>
-        <source>restart</source>
-        <translation type="vanished">reiniciar</translation>
-    </message>
-    <message>
-        <source>shutdown</source>
-        <translation type="vanished">apagar</translation>
-    </message>
-</context>
-<context>
-    <name>SessionWindow</name>
-    <message>
-        <source>select the desktop environment</source>
-        <translation type="obsolete">seleccione el entorno de escritorio</translation>
-    </message>
-    <message>
-        <source> (Default)</source>
-        <translation type="vanished"> (Defecto)</translation>
-    </message>
-</context>
-<context>
-    <name>UserEntry</name>
-    <message>
-        <source>logged in</source>
-        <translation type="vanished">conectado</translation>
+        <source>Suspend</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
