@@ -1,32 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="pt">
-<context>
-    <name>BioAuthentication</name>
-    <message>
-        <source>authentication failed, restart after 2 seconds</source>
-        <translation type="obsolete">autenticação falhou, reinicie após 2 segundos</translation>
-    </message>
-</context>
-<context>
-    <name>BioDeviceView</name>
-    <message>
-        <source>password login</source>
-        <translation type="obsolete">senha de acesso</translation>
-    </message>
-    <message>
-        <source>fingerprint</source>
-        <translation type="obsolete">impressão digital</translation>
-    </message>
-    <message>
-        <source>fingerevin</source>
-        <translation type="obsolete">fingerevin</translation>
-    </message>
-    <message>
-        <source>iris</source>
-        <translation type="obsolete">íris</translation>
-    </message>
-</context>
 <context>
     <name>BiometricAuthWidget</name>
     <message>
@@ -90,12 +64,8 @@
 <context>
     <name>GreeterWindow</name>
     <message>
-        <source>CN</source>
-        <translation type="obsolete">CN</translation>
-    </message>
-    <message>
-        <source>EN</source>
-        <translation type="obsolete">EN</translation>
+        <source>Login</source>
+        <translation type="unfinished">Entrar</translation>
     </message>
 </context>
 <context>
@@ -108,8 +78,12 @@
 <context>
     <name>IconEdit</name>
     <message>
-        <source>Login</source>
-        <translation type="obsolete">Entrar</translation>
+        <source>Password: </source>
+        <translation type="unfinished">Senha: </translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -137,21 +111,9 @@
         <source>Password: </source>
         <translation>Senha: </translation>
     </message>
-    <message>
-        <source>login:</source>
-        <translation type="vanished">entrar:</translation>
-    </message>
     <message>
         <source>Incorrect password, please input again</source>
-        <translation type="unfinished">Senha incorreta, por favor introduza novamente</translation>
-    </message>
-    <message>
-        <source>please select the type of authentication</source>
-        <translation type="obsolete">por favor selecione o tipo de autenticação</translation>
-    </message>
-    <message>
-        <source>Incorrect user name, please input again</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Senha incorreta, por favor introduza novamente</translation>
     </message>
     <message>
         <source>Retry</source>
@@ -173,6 +135,18 @@
         <source>Username</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Authentication failure, Please try again</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please enter your password or enroll your fingerprint </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too many unsuccessful attempts,please enter password.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -183,18 +157,6 @@
 </context>
 <context>
     <name>PowerManager</name>
-    <message>
-        <source>suspend</source>
-        <translation type="obsolete">suspender</translation>
-    </message>
-    <message>
-        <source>restart</source>
-        <translation type="obsolete">reiniciar</translation>
-    </message>
-    <message>
-        <source>shutdown</source>
-        <translation type="obsolete">desligar</translation>
-    </message>
     <message>
         <source>Restart</source>
         <translation type="unfinished"></translation>
@@ -211,50 +173,9 @@
         <source>Sleep</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>PowerWindow</name>
     <message>
-        <source>Goodbye. Would you like to…</source>
-        <translation type="obsolete">Adeus. Você gostaria de…</translation>
-    </message>
-    <message>
-        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
-        <translation type="vanished">Outros usuários estão atualmente conectados a este computador, desligar agora também fechará essas outras sessões.</translation>
-    </message>
-    <message>
-        <source>suspend</source>
-        <translation type="vanished">suspender</translation>
-    </message>
-    <message>
-        <source>hibernate</source>
-        <translation type="vanished">hibernar</translation>
-    </message>
-    <message>
-        <source>restart</source>
-        <translation type="vanished">reiniciar</translation>
-    </message>
-    <message>
-        <source>shutdown</source>
-        <translation type="vanished">desligar</translation>
-    </message>
-</context>
-<context>
-    <name>SessionWindow</name>
-    <message>
-        <source>select the desktop environment</source>
-        <translation type="obsolete">selecione o ambiente de área de trabalho</translation>
-    </message>
-    <message>
-        <source> (Default)</source>
-        <translation type="vanished"> (Padrão)</translation>
-    </message>
-</context>
-<context>
-    <name>UserEntry</name>
-    <message>
-        <source>logged in</source>
-        <translation type="vanished">logado</translation>
+        <source>Suspend</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
