@@ -1,41 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ru_RU">
-<context>
-    <name>BioAuthentication</name>
-    <message>
-        <source>authentication failed, restart after 2 seconds</source>
-        <translation type="obsolete">не удалось идентифицировать, перезапустить после 2 секунды</translation>
-    </message>
-</context>
-<context>
-    <name>BioDeviceView</name>
-    <message>
-        <source>password login</source>
-        <translation type="obsolete">пароль и логин</translation>
-    </message>
-    <message>
-        <source>fingerprint</source>
-        <translation type="obsolete">отпечатки пальцев</translation>
-    </message>
-    <message>
-        <source>fingerevin</source>
-        <translation type="obsolete">палец эвин</translation>
-    </message>
-    <message>
-        <source>iris</source>
-        <translation type="obsolete">айрис</translation>
-    </message>
-</context>
 <context>
     <name>BiometricAuthWidget</name>
     <message>
-        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="100"/>
+        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="99"/>
         <source>Current device: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="163"/>
+        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="170"/>
         <source>Identify failed, Please retry.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -43,22 +17,22 @@
 <context>
     <name>BiometricDevicesWidget</name>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="50"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="51"/>
         <source>Please select the biometric device</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="55"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="56"/>
         <source>Device type:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="72"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="73"/>
         <source>Device name:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="82"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="83"/>
         <source>OK</source>
         <translation type="unfinished"></translation>
     </message>
@@ -99,10 +73,19 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>GreeterWindow</name>
+    <message>
+        <location filename="../greeter/greeterwindow.cpp" line="648"/>
+        <location filename="../greeter/greeterwindow.cpp" line="1007"/>
+        <source>Login</source>
+        <translation type="unfinished">вход</translation>
+    </message>
+</context>
 <context>
     <name>GreeterWrapper</name>
     <message>
-        <location filename="../greeter/greeterwrapper.cpp" line="105"/>
+        <location filename="../greeter/greeterwrapper.cpp" line="116"/>
         <source>failed to start session.</source>
         <translation>не начала сессии.</translation>
     </message>
@@ -110,8 +93,16 @@
 <context>
     <name>IconEdit</name>
     <message>
-        <source>Login</source>
-        <translation type="obsolete">вход</translation>
+        <location filename="../greeter/iconedit.cpp" line="178"/>
+        <location filename="../greeter/iconedit.cpp" line="218"/>
+        <source>Password: </source>
+        <translation type="unfinished">пароль: </translation>
+    </message>
+    <message>
+        <location filename="../greeter/iconedit.cpp" line="180"/>
+        <location filename="../greeter/iconedit.cpp" line="220"/>
+        <source>Username</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -125,70 +116,78 @@
 <context>
     <name>LoginWindow</name>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="267"/>
-        <location filename="../greeter/loginwindow.cpp" line="575"/>
+        <location filename="../greeter/loginwindow.cpp" line="219"/>
+        <location filename="../greeter/loginwindow.cpp" line="308"/>
+        <location filename="../greeter/loginwindow.cpp" line="665"/>
         <source>Login</source>
         <translation>вход</translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="312"/>
+        <location filename="../greeter/loginwindow.cpp" line="353"/>
         <source>logged in</source>
         <translation>войти в систему</translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="392"/>
+        <location filename="../greeter/loginwindow.cpp" line="442"/>
         <source>login</source>
         <translation>вход</translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="480"/>
+        <location filename="../greeter/loginwindow.cpp" line="558"/>
+        <location filename="../greeter/loginwindow.cpp" line="706"/>
+        <source>Please enter your password or enroll your fingerprint </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../greeter/loginwindow.cpp" line="560"/>
         <source>Password: </source>
         <translation>пароль: </translation>
     </message>
     <message>
-        <source>login:</source>
-        <translation type="vanished">вход:</translation>
-    </message>
-    <message>
-        <location filename="../greeter/loginwindow.cpp" line="482"/>
+        <location filename="../greeter/loginwindow.cpp" line="563"/>
         <source>Username</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="539"/>
-        <source>Incorrect user name, please input again</source>
+        <location filename="../greeter/loginwindow.cpp" line="1017"/>
+        <source>Too many unsuccessful attempts,please enter password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="580"/>
-        <location filename="../greeter/loginwindow.cpp" line="789"/>
+        <location filename="../greeter/loginwindow.cpp" line="631"/>
+        <location filename="../greeter/loginwindow.cpp" line="635"/>
+        <location filename="../greeter/loginwindow.cpp" line="1020"/>
+        <source>Authentication failure, Please try again</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../greeter/loginwindow.cpp" line="215"/>
+        <location filename="../greeter/loginwindow.cpp" line="670"/>
+        <location filename="../greeter/loginwindow.cpp" line="926"/>
         <source>Retry</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="754"/>
+        <location filename="../greeter/loginwindow.cpp" line="206"/>
+        <location filename="../greeter/loginwindow.cpp" line="891"/>
         <source>Biometric Authentication</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="767"/>
+        <location filename="../greeter/loginwindow.cpp" line="209"/>
+        <location filename="../greeter/loginwindow.cpp" line="904"/>
         <source>Password Authentication</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="779"/>
+        <location filename="../greeter/loginwindow.cpp" line="212"/>
+        <location filename="../greeter/loginwindow.cpp" line="916"/>
         <source>Other Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/loginwindow.cpp" line="544"/>
-        <location filename="../greeter/loginwindow.cpp" line="549"/>
         <source>Incorrect password, please input again</source>
-        <translation type="unfinished">неверный пароль, пожалуйста, введите снова</translation>
-    </message>
-    <message>
-        <source>please select the type of authentication</source>
-        <translation type="obsolete">пожалуйста, выберите тип аутентификации</translation>
+        <translation type="obsolete">неверный пароль, пожалуйста, введите снова</translation>
     </message>
 </context>
 <context>
@@ -202,100 +201,51 @@
 <context>
     <name>PowerManager</name>
     <message>
-        <location filename="../greeter/powerwindow.cpp" line="131"/>
+        <location filename="../greeter/powerwindow.cpp" line="151"/>
+        <location filename="../greeter/powerwindow.cpp" line="166"/>
         <source>Switch User</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/powerwindow.cpp" line="144"/>
+        <location filename="../greeter/powerwindow.cpp" line="206"/>
+        <source>Suspend</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../greeter/powerwindow.cpp" line="221"/>
         <source>Sleep</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/powerwindow.cpp" line="158"/>
+        <location filename="../greeter/powerwindow.cpp" line="152"/>
+        <location filename="../greeter/powerwindow.cpp" line="179"/>
         <source>Restart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/powerwindow.cpp" line="172"/>
+        <location filename="../greeter/powerwindow.cpp" line="153"/>
+        <location filename="../greeter/powerwindow.cpp" line="192"/>
         <source>Power Off</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>suspend</source>
-        <translation type="obsolete">приостановить</translation>
-    </message>
-    <message>
-        <source>restart</source>
-        <translation type="obsolete">перезагрузка</translation>
-    </message>
-    <message>
-        <source>shutdown</source>
-        <translation type="obsolete">остановка</translation>
-    </message>
-</context>
-<context>
-    <name>PowerWindow</name>
-    <message>
-        <source>Goodbye. Would you like to…</source>
-        <translation type="obsolete">до свидания.хотели бы вы...</translation>
-    </message>
-    <message>
-        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
-        <translation type="vanished">другие пользователи, в настоящее время вход в этот компьютер, закрыв теперь будет также закрыть эти другие занятия.</translation>
-    </message>
-    <message>
-        <source>suspend</source>
-        <translation type="vanished">приостановить</translation>
-    </message>
-    <message>
-        <source>hibernate</source>
-        <translation type="vanished">гибернация</translation>
-    </message>
-    <message>
-        <source>restart</source>
-        <translation type="vanished">перезагрузка</translation>
-    </message>
-    <message>
-        <source>shutdown</source>
-        <translation type="vanished">остановка</translation>
-    </message>
-</context>
-<context>
-    <name>SessionWindow</name>
-    <message>
-        <source>select the desktop environment</source>
-        <translation type="obsolete">выберите окружение рабочего стола</translation>
-    </message>
-    <message>
-        <source> (Default)</source>
-        <translation type="vanished">(по умолчанию)</translation>
-    </message>
-</context>
-<context>
-    <name>UserEntry</name>
-    <message>
-        <source>logged in</source>
-        <translation type="vanished">войти в систему</translation>
-    </message>
 </context>
 <context>
     <name>UsersModel</name>
     <message>
-        <location filename="../greeter/usersmodel.cpp" line="42"/>
-        <location filename="../greeter/usersmodel.cpp" line="44"/>
+        <location filename="../greeter/usersmodel.cpp" line="48"/>
+        <location filename="../greeter/usersmodel.cpp" line="50"/>
         <source>Guest</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../greeter/usersmodel.cpp" line="52"/>
+        <location filename="../greeter/usersmodel.cpp" line="58"/>
         <source>Guest Session</source>
         <translation>гость.</translation>
     </message>
     <message>
-        <location filename="../greeter/usersmodel.cpp" line="70"/>
-        <location filename="../greeter/usersmodel.cpp" line="72"/>
-        <location filename="../greeter/usersmodel.cpp" line="79"/>
+        <location filename="../greeter/usersmodel.cpp" line="76"/>
+        <location filename="../greeter/usersmodel.cpp" line="78"/>
+        <location filename="../greeter/usersmodel.cpp" line="85"/>
         <source>Login</source>
         <translation>вход</translation>
     </message>
